# CHANGELOG

<!-- version list -->

## v1.6.0 (2026-03-15)

### Features

- V2.0.0 — stateless CLI architecture
  ([`62dcd74`](https://github.com/zachary-nguyen/TribalMind/commit/62dcd74540f3360861190e73474031b1b2908b70))


## v1.5.0 (2026-03-14)

### Features

- Update README and enhance CLI aesthetics
  ([`59507a8`](https://github.com/zachary-nguyen/TribalMind/commit/59507a84e706bfe84c20e06ad4b32fe48cd1aa71))


## v1.4.0 (2026-03-14)

### Features

- Add Backboard dashboard UI with assistants, threads, and memory views
  ([`f37e539`](https://github.com/zachary-nguyen/TribalMind/commit/f37e5390fe6c8b466f59228498646dc1aa3ed384))


## v1.3.0 (2026-03-14)

### Features

- Enhance configuration loading and command handling
  ([`ab5a64a`](https://github.com/zachary-nguyen/TribalMind/commit/ab5a64aa3baf3a88bebb509f30be6618ca625e7a))


## v1.2.0 (2026-03-14)


## v1.1.0 (2026-03-14)


## v1.0.0 (2026-03-14)

- Initial Release
